"use strict";
exports.createBus = () => {
    let allSubscribers = {};
    return {
        signal: (eventType) => {
            let subscribers = allSubscribers[eventType];
            if (subscribers) {
                subscribers.forEach(s => s());
            }
        },
        register: (type, callback) => {
            let subscribers = allSubscribers[type];
            if (!subscribers) {
                subscribers = allSubscribers[type] = [];
            }
            subscribers.push(callback);
        },
        unregister: (callback) => {
            Object.keys(allSubscribers).forEach(eventType => {
                let subscribers = allSubscribers[eventType];
                let index = subscribers.indexOf(callback);
                if (index >= 0) {
                    subscribers.splice(index, 1);
                }
            });
        }
    };
};
//# sourceMappingURL=bus.js.map