"use strict";
const util_1 = require("../util");
const typescript_formatter_1 = require("typescript-formatter");
let replaceOptions = {
    replace: true,
    verbose: false,
    baseDir: process.cwd(),
    editorconfig: true,
    tslint: true,
    tsfmt: true,
    verify: false,
    tsconfig: undefined
};
let verifyOptions = {
    replace: false,
    verbose: false,
    baseDir: process.cwd(),
    editorconfig: true,
    tslint: true,
    tsfmt: true,
    verify: true,
    tsconfig: undefined
};
;
exports.createFormatter = (config) => {
    let { logger, bus, git } = config;
    let runFormatter = (options) => {
        return git.findChangedFiles().then(files => {
            files = files.filter(util_1.isTypescriptFile);
            logger.log('formatter', `checking ${files.length} files...`);
            return typescript_formatter_1.processFiles(files, options).then(resultMap => {
                let success = true;
                Object.keys(resultMap).forEach(fileName => {
                    let result = resultMap[fileName];
                    if (result.error) {
                        success = false;
                    }
                    if (result.message) {
                        logger.log('formatter', `${util_1.absolutePath(fileName)}: ${result.message}`);
                    }
                });
                return success;
            });
        });
    };
    let verifyFormat = () => {
        // needs re-entrant fix
        return runFormatter(verifyOptions).then((success) => {
            logger.log('formatter', success ? 'all files formatted' : 'unformatted files found');
            bus.signal(success ? 'format-verified' : 'format-errored');
        });
    };
    return {
        format: () => {
            return runFormatter(replaceOptions);
        },
        startVerifying: (trigger) => {
            bus.register(trigger, verifyFormat);
        },
        stopVerifying: () => {
            bus.unregister(verifyFormat);
        }
    };
};
//# sourceMappingURL=formatter.js.map