"use strict";
const fs_1 = require("fs");
const tslint_1 = require("tslint");
let configurationFile = tslint_1.Linter.loadConfigurationFromPath(process.cwd() + '/tslint.json');
let configuration = {
    rules: configurationFile.rules,
    rulesDirectory: configurationFile.rulesDirectory
};
let options = {
    fix: false,
    formatter: 'prose'
};
process.on('message', (msg) => {
    let success = true;
    let linter = new tslint_1.Linter(options);
    msg.filesToLint.forEach((fileName) => {
        let contents = fs_1.readFileSync(fileName, 'utf8');
        linter.lint(fileName, contents, configuration);
        let results = linter.getResult();
        results.failures.forEach((failure) => {
            success = false;
            let response = {
                violation: {
                    fileName,
                    line: failure.getStartPosition().getLineAndCharacter().line + 1,
                    column: failure.getStartPosition().getLineAndCharacter().character,
                    message: failure.getFailure()
                }
            };
            process.send(response);
        });
    });
    process.send({ finished: { success } });
});
//# sourceMappingURL=linter-process.js.map