"use strict";
const util_1 = require("../util");
const child_process_1 = require("child_process");
;
exports.createLinter = (config) => {
    let { logger, bus, git } = config;
    let lintProcess;
    let running = false;
    let rescheduled = false;
    let startLint = () => {
        rescheduled = false;
        running = true;
        git.findChangedFiles().then((files) => {
            files = files.filter(util_1.isTypescriptFile);
            logger.log('linter', `Linting ${files.length} files...`);
            let command = {
                filesToLint: files
            };
            lintProcess.send(command);
        });
    };
    let lint = () => {
        if (rescheduled) {
            return;
        }
        else if (running) {
            rescheduled = true;
        }
        else {
            startLint();
        }
    };
    return {
        start: (trigger) => {
            lintProcess = child_process_1.fork(__dirname + '/linter-process', [], {});
            lintProcess.on('close', (code) => {
                logger.log('linter', 'linting process exited with code ' + code);
            });
            lintProcess.on('message', (response) => {
                if (response.violation) {
                    let { fileName, line, column, message } = response.violation;
                    logger.log('linter', `${util_1.absolutePath(fileName)}:${line}:${column} ${message}`);
                }
                if (response.finished) {
                    running = false;
                    logger.log('linter', response.finished.success ? 'All files are ok' : 'Linting problems found');
                    bus.signal(response.finished.success ? 'lint-linted' : 'lint-errored');
                    if (rescheduled) {
                        startLint();
                    }
                }
            });
            bus.register(trigger, lint);
        },
        stop: () => {
            bus.unregister(lint);
            lintProcess.kill();
            lintProcess = undefined;
        }
    };
};
//# sourceMappingURL=linter.js.map