"use strict";
const inquirer_1 = require("inquirer");
const path_1 = require("path");
exports.release = (toolbox) => {
    let { git, taskRunner, logger } = toolbox;
    return git.execute(['status', '--porcelain']).then(modifiedFiles => {
        if (modifiedFiles.length > 0) {
            throw new Error('There are uncommitted changes in the working tree');
        }
        let npm = path_1.sep === '\\' ? 'npm.cmd' : 'npm';
        return inquirer_1.prompt({
            type: 'list',
            name: 'bump',
            message: 'What type of bump would you like to do?',
            choices: ['patch', 'minor', 'major']
        }).then(answers => {
            let importance = answers['bump'];
            return taskRunner.runTask(npm, ['version', importance], { name: 'npm', logger }).result.then(() => {
                // 'npm version' also does a 'git commit' and 'git tag'
                return git.execute(['push']).then(() => {
                    return git.execute(['push', '--tags']).then(() => {
                        return taskRunner.runTask(npm, ['publish'], { name: 'npm', logger }).result;
                    });
                });
            });
        });
    });
};
//# sourceMappingURL=release.js.map