"use strict";
const util_1 = require("./util");
exports.createCompiler = (config) => {
    let { taskRunner, logger, bus } = config;
    let busy = true;
    let errors = [];
    let handleOutput = (line) => {
        if (/Starting incremental compilation...$/.test(line)) {
            busy = true;
            logger.log('compiler', 'compiling...');
            errors = [];
            bus.signal('compile-started');
        }
        else if (/Compilation complete\. Watching for file changes.$/.test(line)) {
            busy = false;
            logger.log('compiler', `ready, found ${errors.length} errors`);
            bus.signal(errors.length === 0 ? 'compile-compiled' : 'compile-errored');
        }
        else {
            let matches = /([^(]+)\((\d+),(\d+)\): (error TS\d+: )?(.*)$/.exec(line);
            if (matches) {
                errors.push(matches[0]);
                logger.log('compiler', `${util_1.absolutePath(matches[1])}:${matches[2]}:${matches[3]} ${matches[5]}`);
            }
            else {
                matches = /error TS\d+: (.+)$/.exec(line);
                if (matches) {
                    errors.push(matches[1]);
                    logger.log('compiler', `${matches[1]}`);
                }
                else {
                    // just echo the output
                    logger.log('compiler', line);
                }
            }
        }
        return true;
    };
    let task;
    return {
        start: () => {
            task = taskRunner.runTask('./node_modules/.bin/tsc', ['--watch'], {
                name: 'tsc',
                logger,
                handleOutput
            });
            return task.result;
        },
        stop: () => {
            task.kill();
            task = undefined;
        }
    };
};
//# sourceMappingURL=compiler.js.map