"use strict";
const glob = require("glob");
exports.createGit = (config) => {
    let { taskRunner, logger } = config;
    let git = {
        findChangedFiles: (sinceLastPush) => {
            let fallback = () => {
                // If not inside a git repository or no changed files found:
                return new Promise((resolve, reject) => {
                    glob('**/*.ts', { ignore: ['node_modules/**', 'typings/**'] }, (error, matches) => {
                        if (error) {
                            reject(error);
                        }
                        else {
                            resolve(matches);
                        }
                    });
                });
            };
            let args = sinceLastPush ? ['diff', '--name-only', '--diff-filter=ACM', 'origin/HEAD', 'HEAD'] : ['diff', '--name-only', '--diff-filter=ACM', 'HEAD'];
            return git.execute(args).then((files) => {
                return files;
            }, fallback);
        },
        execute: (args) => {
            let lines = [];
            return taskRunner.runTask('git', args, {
                name: 'git',
                logger,
                handleOutput: (line) => {
                    lines.push(line);
                    return true;
                }
            }).result.then(() => {
                return lines;
            });
        }
    };
    return git;
};
//# sourceMappingURL=git.js.map