#!/usr/bin/env node
"use strict";
const logger_1 = require("./logger");
const taskrunner_1 = require("./taskrunner");
const compiler_1 = require("./compiler");
const formatter_1 = require("./code-style/formatter");
const linter_1 = require("./code-style/linter");
const mocha_1 = require("./testing/mocha");
const bus_1 = require("./bus");
const git_1 = require("./git");
const configuration_1 = require("./configuration");
const index_1 = require("./commands/index");
const path_1 = require("path");
let logger = logger_1.createConsoleLogger();
let taskRunner = path_1.sep === '\\' ? taskrunner_1.createWindowsTaskRunner() : taskrunner_1.createDefaultTaskRunner();
let bus = bus_1.createBus();
let argsOk = false;
let configuration = configuration_1.createConfiguration();
let compiler = compiler_1.createCompiler({ taskRunner, logger, bus });
let git = git_1.createGit({ taskRunner, logger });
let formatter = formatter_1.createFormatter({ git, logger, bus });
let linter = linter_1.createLinter({ taskRunner, git, logger, bus });
let mocha = mocha_1.createMocha({ configuration, taskRunner, logger, bus, git });
let toolbox = {
    compiler, git, formatter, linter, mocha, configuration, bus, logger, taskRunner
};
if (process.argv.length === 3) {
    let command = process.argv[2];
    if (command === 'commit' || command === 'c') {
        // commit: format+compile+lint
        argsOk = true;
        index_1.commands.commit(toolbox);
    }
    else if (command === 'clean') {
        argsOk = true;
        index_1.commands.clean(toolbox);
    }
    else if (command === 'release') {
        argsOk = true;
        index_1.commands.release(toolbox).then(() => {
            console.log('Done');
        }, (error) => {
            console.error(error);
            process.exit(1);
        });
    }
}
else if (process.argv.length === 2) {
    // Normal operation: keep compiling+checking-format+linting
    argsOk = true;
    index_1.commands.assist(toolbox);
}
if (!argsOk) {
    console.error('Usage: tsa || tsa c[ommit] || tsa release || tsa clean');
    process.exit(1);
}
//# sourceMappingURL=index.js.map