"use strict";
const child_process_1 = require("child_process");
let trimAndSplit = (data) => {
    if (!data) {
        return [];
    }
    if (data instanceof Buffer) {
        // meaning data is a Buffer somehow...
        data = data.toString();
    }
    return data.split('\n').map(line => /^\s*(.*?)\s*$/m.exec(line)[1]).filter(line => line.length > 0);
};
exports.createDefaultTaskRunner = () => {
    return {
        runTask: (command, args, config) => {
            let loggerCategory = config.name;
            let logger = config.logger;
            logger.log(loggerCategory, `running command ${command} ${args.join(' ')}`);
            let task = child_process_1.spawn(command, args);
            task.stdout.on('data', (data) => {
                trimAndSplit(data).forEach((line) => {
                    let handled = false;
                    if (config.handleOutput) {
                        handled = config.handleOutput(line);
                    }
                    if (!handled) {
                        logger.log(loggerCategory, line);
                    }
                });
            });
            task.stderr.on('data', (data) => {
                trimAndSplit(data).forEach((line) => {
                    let handled = false;
                    if (config.handleError) {
                        handled = config.handleError(line);
                    }
                    if (!handled) {
                        logger.error(loggerCategory, line);
                    }
                });
            });
            let result = new Promise((resolve, reject) => {
                task.on('close', (code) => {
                    if (!code) {
                        resolve();
                    }
                    else {
                        reject('Process exited with code ' + code);
                    }
                });
            });
            return {
                result,
                kill: () => {
                    task.kill();
                }
            };
        }
    };
};
exports.createWindowsTaskRunner = () => {
    let delegate = exports.createDefaultTaskRunner();
    let translateToWindows = (command) => {
        if (command.charAt(0) === '.') {
            // we just assume it is something from the ./node_modules/.bin/ folder
            command += '.cmd';
        }
        return command.replace(/\//g, '\\');
    };
    return {
        runTask: (command, args, config) => {
            return delegate.runTask(translateToWindows(command), args, config);
        }
    };
};
//# sourceMappingURL=taskrunner.js.map