"use strict";
const Mocha = require("mocha");
require('source-map-support').install();
let sendResponse = (response) => {
    process.send(response);
};
class CustomReporter {
    constructor(runner) {
        runner.on('fail', function (test, err) {
            sendResponse({
                testResult: {
                    fileName: test.file,
                    title: test.title,
                    error: err.message,
                    stack: err.stack
                }
            });
        });
        runner.on('pass', function (test) {
            sendResponse({
                testResult: {
                    fileName: test.file,
                    title: test.title
                }
            });
        });
    }
}
let mocha = new Mocha({ reporter: CustomReporter });
process.on('message', (msg) => {
    msg.testFiles.forEach(testFile => {
        mocha.addFile(testFile);
    });
    mocha.run((failures) => {
        sendResponse({ finished: { success: failures === 0 } });
        process.exit(0);
    });
});
//# sourceMappingURL=mocha-process.js.map