"use strict";
const child_process_1 = require("child_process");
let relevantStackPart = (stack) => {
    let lines = stack.split('\n');
    for (let i = 0; i < lines.length; i++) {
        if (lines[i].indexOf('node_modules\\mocha') !== -1) {
            return lines.slice(0, i).join('\n');
        }
    }
    return stack;
};
exports.createMocha = (config) => {
    let { logger, bus, configuration } = config;
    let startMochaProcess = () => {
        let mochaProcess = child_process_1.fork(__dirname + '/mocha-process', [], {});
        mochaProcess.on('close', (code) => {
            if (code) {
                logger.log('mocha', 'mocha process exited with code ' + code);
            }
        });
        mochaProcess.on('message', (response) => {
            if (response.testResult) {
                let { fileName, title, error, stack } = response.testResult;
                if (error) {
                    logger.log('mocha', `Test failed: ${fileName} ${title}`);
                    logger.log('mocha', relevantStackPart(stack));
                }
            }
            if (response.finished) {
                logger.log('mocha', response.finished.success ? 'All tests pass' : 'There were test failures');
            }
        });
        return mochaProcess;
    };
    let startMocha = () => {
        configuration.findCompiledTestFiles().then((files) => {
            logger.log('mocha', `Testing ${files.length} files...`);
            let command = {
                testFiles: files
            };
            startMochaProcess().send(command);
        });
    };
    return {
        start: (trigger) => {
            bus.register(trigger, startMocha);
        },
        stop: () => {
            bus.unregister(startMocha);
        }
    };
};
//# sourceMappingURL=mocha.js.map